module.exports = {
  "extends": "airbnb-base",
  "rules": {
    // ERRORS

    // disallow usage of expressions in statement position
    "no-await-in-loop": 0,

    // disallow the use of console
    "no-console": ["error", {
      "allow": ["error"]
    }],


    // BEST PRACTICES

    // disallow reassignment of function parameters
    // allow parameter object manipulation
    "no-param-reassign": ["error", {
      "props": false
    }],

    // disallow unused expressions
    "no-unused-expressions": ["error", {
      "allowShortCircuit": true,
      "allowTernary": false
    }],


    // STRICT MODE

    // require or disallow strict mode directives
    "strict": 0,


    // STYLE

    // require or disallow trailing commas
    "comma-dangle": 0,

    // require or disallow newline at the end of files
    "eol-last": 0,

    // disallow use of bitwise operators
    "no-bitwise": ["error", {
      "allow": ["~"]
    }],

    // disallow dangling underscores in identifiers
    "no-underscore-dangle": ["error", {
      "allow": ["_id"],
      "allowAfterThis": false
    }],

    // require JSDoc comments
    "require-jsdoc": [
      "error", {
        "require": {
          "FunctionDeclaration": true,
          "MethodDefinition": true,
          "ClassDeclaration": true
        }
      }
    ],

    // require or disallow semicolons instead of ASI
    "semi": [2, "never"],

    // enforce consistent spacing after the // or /* in a comment
    "spaced-comment": [
      "error",
      "always"
    ],


    // IMPORT PLUGIN

    // Forbid the use of extraneous packages
    // https://github.com/benmosher/eslint-plugin-import/blob/master/docs/rules/no-extraneous-dependencies.md
    // paths are treated both as absolute paths, and relative to process.cwd()
    "import/no-extraneous-dependencies": ["error", {
      "devDependencies": [
        "test/**", // tape, common npm pattern
        "tests/**", // also common npm pattern
        "spec/**", // mocha, rspec-like pattern
        "**/__tests__/**", // jest pattern
        "test.js", // repos with a single test file
        "test-*.js", // repos with multiple top-level test files
        "**/*.spec.js", // tests where the extension denotes that it is a spec
        "**/*.test.js", // tests where the extension denotes that it is a test
        "**/webpack.config.js", // webpack config
        "**/webpack.config.*.js", // webpack config
        "**/rollup.config.js", // rollup config
        "**/gulpfile.js", // gulp config
        "**/gulpfile.*.js", // gulp config
        "**/Gruntfile" // grunt config
      ],
      "optionalDependencies": false
    }]
  }
}